==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/da.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Der mangler kodeord for gendannelsesnøgle",
    "Please repeat the recovery key password" : "Gentag venligst kodeordet for gendannelsesnøglen",
    "Repeated recovery key password does not match the provided recovery key password" : "Det gentagne kodeord for gendannelsesnøglen stemmer ikke med det angivne kodeord for gendannelsesnøglen",
    "Recovery key successfully enabled" : "Gendannelsesnøgle aktiveret med succes",
    "Could not enable recovery key. Please check your recovery key password!" : "Kunne ikke aktivere gendannelsesnøgle. Kontroller venligst dit gendannelsesnøgle kodeord!",
    "Recovery key successfully disabled" : "Gendannelsesnøgle deaktiveret succesfuldt",
    "Could not disable recovery key. Please check your recovery key password!" : "Kunne ikke deaktivere gendannelsesnøgle. Kontroller din gendannelsesnøgle kodeord!",
    "Missing parameters" : "Manglende parametre",
    "Please provide the old recovery password" : "Angiv venligst det gamle kodeord for gendannelsesnøglen",
    "Please provide a new recovery password" : "Angiv venligst et nyt kodeord til gendannelse",
    "Please repeat the new recovery password" : "Gentag venligst det nye kodeord til gendannelse",
    "Password successfully changed." : "Kodeordet blev ændret succesfuldt",
    "Could not change the password. Maybe the old password was not correct." : "Kunne ikke ændre kodeordet. Måske var det gamle kodeord ikke korrekt.",
    "Recovery Key disabled" : "Gendannelsesnøgle er slået fra",
    "Recovery Key enabled" : "Gendannalsesnøgle aktiv",
    "Could not enable the recovery key, please try again or contact your administrator" : "Kunne ikke aktivere gendannelsesnøglen, venligst prøv igen eller kontakt din administrator",
    "Could not update the private key password." : "Kunne ikke opdatere kodeordet til den private nøgle.",
    "The old password was not correct, please try again." : "Det gamle kodeord var ikke korrekt, prøv venligst igen.",
    "The current log-in password was not correct, please try again." : "Det nuværende kodeord til log-in var ikke korrekt, prøv venligst igen.",
    "Private key password successfully updated." : "Privat nøgle kodeord succesfuldt opdateret.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Du skal overflytte dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye af slagsen. Kør venligst \"occ encryption:migrate\" eller kontakt din administrator.",
    "Bad Signature" : "Ugyldig signatur",
    "Missing Signature" : "Signatur mangler",
    "one-time password for server-side-encryption" : "Engangs password for kryptering på serverdelen",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke kryptere denne fil, sandsynligvis fordi filen er delt. Bed venligst filens ejer om at dele den med dig på ny.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke læse denne fil, sandsynligvis fordi det er en delt fil. Bed venligst ejeren af filen om at dele filen med dig på ny.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hejsa,\n\nadministrator aktiveret kryptering på serverdelen. '%s'.\n\nVenligst log på web brugerfladen, gå til sektionen \"grundlæggende krypterings modul\" for din personlige opsætninger og opdater dine krypterings kodeord ved at indtaste dette kodeord i \"gamle kodeord log\" feltet samt dit nuværende kodeord.\n\n",
    "The share will expire on %s." : "Delingen vil udløbe om %s.",
    "Cheers!" : "Hej!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hejsa,<br><br>administrator aktiveret kryptering på serverdelen. Dine file er blevet krypteret med kodeordet <strong>%s</strong>.<br><br>Venligst log på web brugerfladen, gå til sektionen \"grundlæggende krypterings modul\" for din personlige opsætninger og opdater dine krypterings kodeord ved at indtaste dette kodeord i \"gamle kodeord log\" feltet samt dit nuværende kodeord.<br><br>",
    "Encrypt the home storage" : "Krypter hjemmelageret",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ved at slå denne valgmulighed til krypteres alle filer i hovedlageret, ellers vil kun filer på eksternt lager blive krypteret",
    "Enable recovery key" : "Aktivér gendannelsesnøgle",
    "Disable recovery key" : "Deaktivér gendannelsesnøgle",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Gendannelsesnøglen er en ekstra krypteringsnøgle, der bruges til at kryptere filer. Den tillader gendannelse af en brugers filer, hvis brugeren glemmer sin adgangskode.",
    "Recovery key password" : "Gendannelsesnøgle kodeord",
    "Repeat recovery key password" : "Gentag adgangskode for gendannelsesnøgle",
    "Change recovery key password:" : "Skift gendannelsesnøgle kodeord:",
    "Old recovery key password" : "Gammel adgangskode for gendannelsesnøgle",
    "New recovery key password" : "Ny adgangskode for gendannelsesnøgle",
    "Repeat new recovery key password" : "Gentag ny adgangskode for gendannelsesnøgle",
    "Change Password" : "Skift Kodeord",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Krypteringsprogrammet er aktiveret, men din nøgler er ikke igangsat. Log venligst ud og ind igen.",
    "Your private key password no longer matches your log-in password." : "Dit private nøglekodeord stemmer ikke længere overens med dit login-kodeord.",
    "Set your old private key password to your current log-in password:" : "Sæt dit gamle, private nøglekodeord til at være dit nuværende login-kodeord. ",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Hvis du ikke kan huske dit gamle kodeord kan du bede din administrator om at gendanne dine filer.",
    "Old log-in password" : "Gammelt login kodeord",
    "Current log-in password" : "Nuvrende login kodeord",
    "Update Private Key Password" : "Opdater Privat Nøgle Kodeord",
    "Enable password recovery:" : "Aktiver kodeord gendannelse:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aktivering af denne valgmulighed tillader dig at generhverve adgang til dine krypterede filer i tilfælde af tab af kodeord",
    "Enabled" : "Aktiveret",
    "Disabled" : "Deaktiveret"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/da.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Der mangler kodeord for gendannelsesnøgle",
    "Please repeat the recovery key password" : "Gentag venligst kodeordet for gendannelsesnøglen",
    "Repeated recovery key password does not match the provided recovery key password" : "Det gentagne kodeord for gendannelsesnøglen stemmer ikke med det angivne kodeord for gendannelsesnøglen",
    "Recovery key successfully enabled" : "Gendannelsesnøgle aktiveret med succes",
    "Could not enable recovery key. Please check your recovery key password!" : "Kunne ikke aktivere gendannelsesnøgle. Kontroller venligst dit gendannelsesnøgle kodeord!",
    "Recovery key successfully disabled" : "Gendannelsesnøgle deaktiveret succesfuldt",
    "Could not disable recovery key. Please check your recovery key password!" : "Kunne ikke deaktivere gendannelsesnøgle. Kontroller din gendannelsesnøgle kodeord!",
    "Missing parameters" : "Manglende parametre",
    "Please provide the old recovery password" : "Angiv venligst det gamle kodeord for gendannelsesnøglen",
    "Please provide a new recovery password" : "Angiv venligst et nyt kodeord til gendannelse",
    "Please repeat the new recovery password" : "Gentag venligst det nye kodeord til gendannelse",
    "Password successfully changed." : "Kodeordet blev ændret succesfuldt",
    "Could not change the password. Maybe the old password was not correct." : "Kunne ikke ændre kodeordet. Måske var det gamle kodeord ikke korrekt.",
    "Recovery Key disabled" : "Gendannelsesnøgle er slået fra",
    "Recovery Key enabled" : "Gendannalsesnøgle aktiv",
    "Could not enable the recovery key, please try again or contact your administrator" : "Kunne ikke aktivere gendannelsesnøglen, venligst prøv igen eller kontakt din administrator",
    "Could not update the private key password." : "Kunne ikke opdatere kodeordet til den private nøgle.",
    "The old password was not correct, please try again." : "Det gamle kodeord var ikke korrekt, prøv venligst igen.",
    "The current log-in password was not correct, please try again." : "Det nuværende kodeord til log-in var ikke korrekt, prøv venligst igen.",
    "Private key password successfully updated." : "Privat nøgle kodeord succesfuldt opdateret.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Du skal overflytte dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye af slagsen. Kør venligst \"occ encryption:migrate\" eller kontakt din administrator.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Ugyldig privat nøgle til Krypteringsprogrammet. Venligst opdater din kode til privat nøgle i dine personlige indstillinger for at gendanne adgang til dine krypterede filer.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Krypteringsprogrammet er aktiveret, men dine nøgler er ikke indlæst. Log venligst ud og ind igen.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Venligst aktiver Server kryptering under administrationen hvis du vil anvende krypterings modulet.",
    "Encryption app is enabled and ready" : "Krypteringsprogrammet er aktiveret og klar",
    "Bad Signature" : "Ugyldig signatur",
    "Missing Signature" : "Signatur mangler",
    "one-time password for server-side-encryption" : "Engangs password for kryptering på serverdelen",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke kryptere denne fil, sandsynligvis fordi filen er delt. Bed venligst filens ejer om at dele den med dig på ny.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke læse denne fil, sandsynligvis fordi det er en delt fil. Bed venligst ejeren af filen om at dele filen med dig på ny.",
    "Default encryption module" : "Standard krypterings modul",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hej,\n\nAdministrator aktiveret kryptering på serverdelen. '%s'.\n\nVenligst log på web brugerfladen, gå til sektionen \"grundlæggende krypterings modul\" for din personlige opsætninger og opdater dine krypterings kodeord ved at indtaste dette kodeord i \"gamle kodeord log\" feltet samt dit nuværende kodeord.\n\n",
    "The share will expire on %s." : "Delingen vil udløbe om %s.",
    "Cheers!" : "Hej!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hej,<br><br>administrator aktiveret kryptering på serverdelen. Dine file er blevet krypteret med kodeordet <strong>%s</strong>.<br><br>Venligst log på web brugerfladen, gå til sektionen \"grundlæggende krypterings modul\" for din personlige opsætninger og opdater dine krypterings kodeord ved at indtaste dette kodeord i \"gamle kodeord log\" feltet samt dit nuværende kodeord.<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Krypteringsprogrammet er aktiveret men dine nøgler er ikke indlæst, log venligst ud og ind igen",
    "Encrypt the home storage" : "Krypter hjemmelageret",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ved at slå denne valgmulighed til krypteres alle filer i hovedlageret, ellers vil kun filer på eksternt lager blive krypteret",
    "Enable recovery key" : "Aktivér gendannelsesnøgle",
    "Disable recovery key" : "Deaktivér gendannelsesnøgle",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Gendannelsesnøglen er en ekstra krypteringsnøgle, der bruges til at kryptere filer. Den tillader gendannelse af en brugers filer, hvis brugeren glemmer sin adgangskode.",
    "Recovery key password" : "Gendannelsesnøgle kodeord",
    "Repeat recovery key password" : "Gentag adgangskode for gendannelsesnøgle",
    "Change recovery key password:" : "Skift gendannelsesnøgle kodeord:",
    "Old recovery key password" : "Gammel adgangskode for gendannelsesnøgle",
    "New recovery key password" : "Ny adgangskode for gendannelsesnøgle",
    "Repeat new recovery key password" : "Gentag ny adgangskode for gendannelsesnøgle",
    "Change Password" : "Skift Kodeord",
    "Basic encryption module" : "Basis krypterings modul",
    "Your private key password no longer matches your log-in password." : "Dit private nøglekodeord stemmer ikke længere overens med dit login-kodeord.",
    "Set your old private key password to your current log-in password:" : "Sæt dit gamle, private nøglekodeord til at være dit nuværende login-kodeord. ",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Hvis du ikke kan huske dit gamle kodeord kan du bede din administrator om at gendanne dine filer.",
    "Old log-in password" : "Gammelt login kodeord",
    "Current log-in password" : "Nuvrende login kodeord",
    "Update Private Key Password" : "Opdater Privat Nøgle Kodeord",
    "Enable password recovery:" : "Aktiver kodeord gendannelse:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aktivering af denne valgmulighed tillader dig at generhverve adgang til dine krypterede filer i tilfælde af tab af kodeord",
    "Enabled" : "Aktiveret",
    "Disabled" : "Deaktiveret",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Krypteringsprogrammet er aktiveret, men din nøgler er ikke igangsat. Log venligst ud og ind igen."
},
"nplurals=2; plural=(n != 1);");
